clear;

x = loadsig('testfft.tr0');

fs = 1/10e-12;

y1 = evalsig(x,'rfbit10');
y2 = evalsig(x,'rfpwmnoncenter');
y3 = evalsig(x,'rfpwmampapprox');
y4 = evalsig(x,'rfpwmphapprox');
y5 = evalsig(x,'rfpwmnoph');

%%

rbw = 100e3;
[YdB1,f] = fun_calc_psd(y1,fs,rbw);
[YdB2,f] = fun_calc_psd(y2,fs,rbw);
[YdB3,f] = fun_calc_psd(y3,fs,rbw);
[YdB4,f] = fun_calc_psd(y4,fs,rbw);
[YdB5,f] = fun_calc_psd(y5,fs,rbw);

%%

figure(1);
h0 = figure(1);
set(h0,'Position',[646 200 560*1.07 420*1.07]);
clf;
plot(f/1e9,YdB1,'r-',f/1e9,YdB2,'k-',f/1e9,YdB5,'b-');
hold on;
plot([0.9617 1.0217],[-156 -156],'k',[1.0617 1.1217],[-156 -156],'k','LineWidth',4);
hold off;
grid on;
ylabel('PSD (dB)');
xlabel('Frequency (GHz)');
title('Output Spectrum of DPA (dB)');
st = ['no phase compensation';
      'with noncentered PWM '];
[legend_h,object_h,plot_h,text_strings]= ...
    legend('10-bit DPA','noncentered PWM',st);
set(object_h,'LineWidth',3);
axis([1.0417-0.2 1.0417+0.2 -180 -120]);
text(0.95,-134,'10-bit DPA','BackgroundColor',[1 1 1]);
text(0.975,-137,'\downarrow');
text(0.97,-173.5,'noncentered PWM','BackgroundColor',[1 1 1]);
text(0.987,-171.5,'\uparrow');
text(0.95,-123,'upconverted','BackgroundColor',[1 1 1]);
text(0.94,-125.5,'baseband signal','BackgroundColor',[1 1 1]);
text(1.026,-124.25,'\rightarrow');
text(1.065,-159.6,'3GPP mask','BackgroundColor',[1 1 1]);
text(1.085,-157.3,'\downarrow');

%%
figure(2);
h0 = figure(2);
set(h0,'Position',[646 10 560*1.07 600*1.07]);
clf;
subplot(211);
plot(f/1e9,YdB2,'k-',f/1e9,YdB3,'r-');
hold on;
plot([0.9617 1.0217],[-156 -156],'k',[1.0617 1.1217],[-156 -156],'k','LineWidth',4);
text(0.89,-158.5,'3GPP mask','BackgroundColor',[1 1 1]);
text(0.953,-157.5,'\leftarrow','Rotation',45);
grid on;
ylabel('PSD (dB)');
xlabel('Frequency (GHz)');
axis([1.0417-0.2 1.0417+0.2 -175 -145]);
title('noncentered PWM with amp approximation');
st = ['noncentered PWM  ';
      'amp approximation'];
[legend_h,object_h,plot_h,text_strings]= ...
    legend('noncentered PWM',st);
set(object_h,'LineWidth',3);
subplot(212);
plot(f/1e9,YdB2-YdB3,'k-');
axis([1.0417-0.2 1.0417+0.2 -0.2 0.4]);
ylabel('PSD difference (dB)');
xlabel('Frequency (GHz)');
grid on;
title('Difference between PSD with and without amp approximation');

figure(3);
h0 = figure(3);
set(h0,'Position',[646 10 560*1.07 600*1.07]);
clf;
subplot(211);
plot(f/1e9,YdB2,'k-',f/1e9,YdB4,'r-');
hold on;
plot([0.9617 1.0217],[-156 -156],'k',[1.0617 1.1217],[-156 -156],'k','LineWidth',4);
text(0.89,-158.5,'3GPP mask','BackgroundColor',[1 1 1]);
text(0.953,-157.5,'\leftarrow','Rotation',45);
grid on;
ylabel('PSD (dB)');
xlabel('Frequency (GHz)');
axis([1.0417-0.2 1.0417+0.2 -175 -145]);
title('noncentered PWM with phase approximation');
st = ['noncentered PWM    ';
      'phase approximation'];
[legend_h,object_h,plot_h,text_strings]= ...
    legend('noncentered PWM',st);
set(object_h,'LineWidth',3);
subplot(212);
plot(f/1e9,YdB2-YdB4,'k-');
axis([1.0417-0.2 1.0417+0.2 -0.2 0.4]);
ylabel('PSD difference (dB)');
xlabel('Frequency (GHz)');
grid on;
title('Difference between PSD with and without phase approximation');
